@@ -1,3 +1,4 @@
+import json
 import torch
 import random
 
@@ -46,6 +47,7 @@ from ....misc.toolkit import slerp
 from ....misc.toolkit import new_seed
 from ....misc.toolkit import eval_context
 from ....misc.toolkit import download_model
+from ....misc.toolkit import download_static
 from ....misc.toolkit import seed_everything
 from ....modules.blocks import Conv2d
 from ....models.cv.diffusion import LDM
@@ -114,6 +116,8 @@ class SDVersions(str, Enum):
     ANIME = "anime"
     ANIME_ANYTHING = "anime_anything"
     ANIME_HYBRID = "anime_hybrid"
+    ANIME_GUOFENG = "anime_guofeng"
+    ANIME_ORANGE = "anime_orange"
     DREAMLIKE = "dreamlike_v1"
 
 
@@ -126,6 +130,10 @@ def get_sd_tag(version: SDVersions) -> str:
         tag = "anime_anything_v3"
     elif version == SDVersions.ANIME_HYBRID:
         tag = "anime_hybrid_v1"
+    elif version == SDVersions.ANIME_GUOFENG:
+        tag = "anime_guofeng3"
+    elif version == SDVersions.ANIME_ORANGE:
+        tag = "anime_orange2"
     else:
         tag = version
     return f"ldm_sd_{tag}"
@@ -595,7 +603,7 @@ class DiffusionAPI(APIMixin):
 
     def txt2img_inpainting(
         self,
-        txt: str,
+        txt: Union[str, List[str]],
         image: Union[str, Image.Image],
         mask: Union[str, Image.Image],
         export_path: Optional[str] = None,
@@ -604,6 +612,7 @@ class DiffusionAPI(APIMixin):
         reference_fidelity: float = 0.2,
         anchor: int = 64,
         max_wh: int = 512,
+        num_samples: Optional[int] = None,
         num_steps: Optional[int] = None,
         clip_output: bool = True,
         keep_original: bool = False,
@@ -636,7 +645,7 @@ class DiffusionAPI(APIMixin):
                 verbose=verbose,
                 **kwargs,
             )
-        txt_list, num_samples = self._txt_cond(txt, 1)
+        txt_list, num_samples = self._txt_cond(txt, num_samples)
         res = self._get_masked_cond(
             image,
             mask,
@@ -1159,6 +1168,31 @@ class DiffusionAPI(APIMixin):
             )
 
 
+def offset_cnet_weights(d: tensor_dict_type, api: DiffusionAPI) -> tensor_dict_type:
+    with open(download_static("sd_mapping", extension="json"), "r") as f:
+        mapping = json.load(f)
+    with open(download_static("sd_controlnet_mapping", extension="json"), "r") as f:
+        c_mapping = json.load(f)
+    rev_c_mapping = {v: k for k, v in c_mapping.items()}
+    nd = shallow_copy_dict(d)
+    with api.load_context() as wrapper:
+        md = wrapper.state_dict()
+    device = list(md.values())[0].device
+    nd = {k: v.to(device) for k, v in nd.items()}
+    for k, v in nd.items():
+        rev_k = rev_c_mapping[k]
+        original_k = f"model.diffusion_model.{rev_k.split('.', 1)[1]}"
+        mk = mapping.get(original_k)
+        if mk is None:
+            continue
+        mv = md[mk].to(v)
+        # inpainting workaround
+        if k == "input_blocks.0.0.weight" and mv.shape[1] == 9:
+            mv = mv[:, :4]
+        nd[k] = v + mv
+    return nd
+
+
 class ControlNetHints(str, Enum):
     DEPTH = "depth"
     CANNY = "canny"
@@ -1244,12 +1278,13 @@ class ControlledDiffusionAPI(DiffusionAPI):
     loaded: Dict[ControlNetHints, bool]
     weights: Dict[ControlNetHints, tensor_dict_type]
     annotators: Dict[ControlNetHints, Annotator]
+    base_sd_versions: Dict[ControlNetHints, SDVersions]
 
     defaults = {
-        ControlNetHints.DEPTH: "ldm.sd_v1.5.control.depth",
-        ControlNetHints.CANNY: "ldm.sd_v1.5.control.canny",
-        ControlNetHints.POSE: "ldm.sd_v1.5.control.pose",
-        ControlNetHints.MLSD: "ldm.sd_v1.5.control.mlsd",
+        ControlNetHints.DEPTH: "ldm.sd_v1.5.control.diff.depth",
+        ControlNetHints.CANNY: "ldm.sd_v1.5.control.diff.canny",
+        ControlNetHints.POSE: "ldm.sd_v1.5.control.diff.pose",
+        ControlNetHints.MLSD: "ldm.sd_v1.5.control.diff.mlsd",
     }
     annotator_classes: Dict[ControlNetHints, Type[Annotator]] = {
         ControlNetHints.DEPTH: DepthAnnotator,
@@ -1284,6 +1319,7 @@ class ControlledDiffusionAPI(DiffusionAPI):
         self.annotators = {}
         self.num_pool = num_pool
         self.control_model = self.m.control_model
+        self.base_sd_versions = {}
 
     def to(
         self,
@@ -1336,10 +1372,18 @@ class ControlledDiffusionAPI(DiffusionAPI):
 
         sorted_target = sorted(target)
         loaded_list = [self.loaded[hint] for hint in sorted_target]
-        if all(loaded_list):
+        base_list = [self.base_sd_versions.get(hint) for hint in sorted_target]
+        need_offset_list = [
+            base is None
+            or self.current_sd_version is None
+            or get_sd_tag(base) != get_sd_tag(self.current_sd_version)
+            for base in base_list
+        ]
+        if all(loaded_list) and not any(need_offset_list):
             return
-        for loaded, hint in zip(loaded_list, sorted_target):
-            if loaded:
+        iterator = zip(loaded_list, sorted_target, need_offset_list)
+        for loaded, hint, need_offset in iterator:
+            if loaded and not need_offset:
                 continue
             d = self.weights.get(hint)
             if d is None:
@@ -1347,8 +1391,12 @@ class ControlledDiffusionAPI(DiffusionAPI):
                     f"cannot find weights called '{hint}', "
                     f"available weights are: {', '.join(self.available)}"
                 )
+            if need_offset:
+                d = offset_cnet_weights(d, self)
             self.m.load_control_net_with(hint, d)
             self.loaded[hint] = True
+            if self.current_sd_version is not None:
+                self.base_sd_versions[hint] = self.current_sd_version
 
     def prepare_annotator(self, hint: ControlNetHints) -> None:
         if hint not in self.annotators:
